summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@fastmq.commkdir>2009-08-03 11:30:13 +0200
committerMartin Sustrik <sustrik@fastmq.commkdir>2009-08-03 11:30:13 +0200
commitcc3755a16f00026af882ed14d122cc8aa6d50e82 (patch)
tree33a2197bab1bd6068dbfcc446fe70aaa07808fa9 /include
parent183b6887644ac05c951a3f9143248ed86e91052f (diff)
renamed from zs to zmq
Diffstat (limited to 'include')
-rw-r--r--include/zmq.h (renamed from include/zs.h)103
-rw-r--r--include/zmq.hpp (renamed from include/zs.hpp)64
2 files changed, 84 insertions, 83 deletions
diff --git a/include/zs.hpp b/include/zmq.hpp
index d0f607f..317fddf 100644
--- a/include/zs.hpp
+++ b/include/zmq.hpp
@@ -17,30 +17,30 @@
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef __ZSOCKETS_HPP_INCLUDED__
-#define __ZSOCKETS_HPP_INCLUDED__
+#ifndef __ZMQ_HPP_INCLUDED__
+#define __ZMQ_HPP_INCLUDED__
-#include "zs.h"
+#include "zmq.h"
#include <assert.h>
-namespace zs
+namespace zmq
{
- typedef zs_free_fn free_fn;
+ typedef zmq_free_fn free_fn;
enum message_type_t
{
message_data = 1 << 0,
- message_gap = 1 << ZS_GAP,
- message_delimiter = 1 << ZS_DELIMITER
+ message_gap = 1 << ZMQ_GAP,
+ message_delimiter = 1 << ZMQ_DELIMITER
};
// A message. Caution: Don't change the body of the message once you've
// copied it - the behaviour is undefined. Don't change the body of the
// received message either - other threads may be accessing it in parallel.
- class message_t : private zs_msg
+ class message_t : private zmq_msg
{
friend class socket_t;
@@ -49,7 +49,7 @@ namespace zs
// Creates message size_ bytes long.
inline message_t (size_t size_ = 0)
{
- int rc = zs_msg_init_size (this, size_);
+ int rc = zmq_msg_init_size (this, size_);
assert (rc == 0);
}
@@ -60,14 +60,14 @@ namespace zs
inline message_t (void *data_, size_t size_,
free_fn *ffn_)
{
- int rc = zs_msg_init_data (this, data_, size_, ffn_);
+ int rc = zmq_msg_init_data (this, data_, size_, ffn_);
assert (rc == 0);
}
// Destroys the message.
inline ~message_t ()
{
- int rc = zs_msg_close (this);
+ int rc = zmq_msg_close (this);
assert (rc == 0);
}
@@ -76,9 +76,9 @@ namespace zs
// to reuse once-allocated message for multiple times.
inline void rebuild (size_t size_)
{
- int rc = zs_msg_close (this);
+ int rc = zmq_msg_close (this);
assert (rc == 0);
- rc = zs_msg_init_size (this, size_);
+ rc = zmq_msg_init_size (this, size_);
assert (rc == 0);
}
@@ -87,9 +87,9 @@ namespace zs
// deallocation mechanism.
inline void rebuild (void *data_, size_t size_, free_fn *ffn_)
{
- int rc = zs_msg_close (this);
+ int rc = zmq_msg_close (this);
assert (rc == 0);
- rc = zs_msg_init_data (this, data_, size_, ffn_);
+ rc = zmq_msg_init_data (this, data_, size_, ffn_);
assert (rc == 0);
}
@@ -99,7 +99,7 @@ namespace zs
// of data after the operation.
inline void move_to (message_t *msg_)
{
- int rc = zs_msg_move (this, (zs_msg*) msg_);
+ int rc = zmq_msg_move (this, (zmq_msg*) msg_);
assert (rc == 0);
}
@@ -108,26 +108,26 @@ namespace zs
// these get deallocated.
inline void copy_to (message_t *msg_)
{
- int rc = zs_msg_copy (this, (zs_msg*) msg_);
+ int rc = zmq_msg_copy (this, (zmq_msg*) msg_);
assert (rc == 0);
}
// Returns message type.
inline message_type_t type ()
{
- return (message_type_t) (1 << zs_msg_type (this));
+ return (message_type_t) (1 << zmq_msg_type (this));
}
// Returns pointer to message's data buffer.
inline void *data ()
{
- return zs_msg_data (this);
+ return zmq_msg_data (this);
}
// Returns the size of message data buffer.
inline size_t size ()
{
- return zs_msg_size (this);
+ return zmq_msg_size (this);
}
private:
@@ -146,13 +146,13 @@ namespace zs
inline context_t (int app_threads_, int io_threads_)
{
- ptr = zs_init (app_threads_, io_threads_);
+ ptr = zmq_init (app_threads_, io_threads_);
assert (ptr);
}
inline ~context_t ()
{
- int rc = zs_term (ptr);
+ int rc = zmq_term (ptr);
assert (rc == 0);
}
@@ -171,49 +171,49 @@ namespace zs
inline socket_t (context_t &context_, int type_ = 0)
{
- ptr = zs_socket (context_.ptr, type_);
+ ptr = zmq_socket (context_.ptr, type_);
assert (ptr);
}
inline ~socket_t ()
{
- int rc = zs_close (ptr);
+ int rc = zmq_close (ptr);
assert (rc == 0);
}
- inline void bind (const char *addr_, zs_opts *opts_ = NULL)
+ inline void bind (const char *addr_, zmq_opts *opts_ = NULL)
{
- int rc = zs_bind (ptr, addr_, opts_);
+ int rc = zmq_bind (ptr, addr_, opts_);
assert (rc == 0);
}
- inline void connect (const char *addr_, zs_opts *opts_ = NULL)
+ inline void connect (const char *addr_, zmq_opts *opts_ = NULL)
{
- int rc = zs_connect (ptr, addr_, opts_);
+ int rc = zmq_connect (ptr, addr_, opts_);
assert (rc == 0);
}
inline void subscribe (const char *criteria_)
{
- int rc = zs_subscribe (ptr, criteria_);
+ int rc = zmq_subscribe (ptr, criteria_);
assert (rc == 0);
}
inline void send (message_t &msg_, int flags_ = 0)
{
- int rc = zs_send (ptr, &msg_, flags_);
+ int rc = zmq_send (ptr, &msg_, flags_);
assert (rc == 0);
}
inline void flush ()
{
- int rc = zs_flush (ptr);
+ int rc = zmq_flush (ptr);
assert (rc == 0);
}
inline void recv (message_t *msg_, int flags_ = 0)
{
- int rc = zs_recv (ptr, msg_, flags_);
+ int rc = zmq_recv (ptr, msg_, flags_);
assert (rc == 0);
}
diff --git a/include/zs.h b/include/zmq.h
index cae1a17..0fbc142 100644
--- a/include/zs.h
+++ b/include/zmq.h
@@ -17,8 +17,8 @@
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef __ZSOCKETS_H_INCLUDED__
-#define __ZSOCKETS_H_INCLUDED__
+#ifndef __ZMQ_H_INCLUDED__
+#define __ZMQ_H_INCLUDED__
#ifdef __cplusplus
extern "C" {
@@ -27,75 +27,75 @@ extern "C" {
#include <stddef.h>
#include <stdint.h>
-#if defined MSC_VER && defined ZS_BUILDING_LIBZS
-#define ZS_EXPORT __declspec(dllexport)
+#if defined MSC_VER && defined ZMQ_BUILDING_LIBZMQ
+#define ZMQ_EXPORT __declspec(dllexport)
#else
-#define ZS_EXPORT
+#define ZMQ_EXPORT
#endif
// Maximal size of "Very Small Message". VSMs are passed by value
// to avoid excessive memory allocation/deallocation.
-#define ZS_MAX_VSM_SIZE 30
+#define ZMQ_MAX_VSM_SIZE 30
// Message & notification types.
-#define ZS_GAP 1
-#define ZS_DELIMITER 31
-#define ZS_VSM 32
+#define ZMQ_GAP 1
+#define ZMQ_DELIMITER 31
+#define ZMQ_VSM 32
// The operation should be performed in non-blocking mode. I.e. if it cannot
// be processed immediately, error should be returned with errno set to EAGAIN.
#define ZS_NOBLOCK 1
// zs_send should not flush the message downstream immediately. Instead, it
// should batch ZS_NOFLUSH messages and send them downstream only when zs_flush
// is invoked. This is an optimisation for cases where several messages are
// sent in a single business transaction. However, the effect is measurable
// only in extremely high-perf scenarios (million messages a second or so).
// If that's not your case, use standard flushing send instead. See exchange
// example for illustration of ZS_NOFLUSH functionality.
#define ZS_NOFLUSH 2
// Socket to communicate with a single peer. Allows for a singe connect or a
// single accept. There's no message routing or message filtering involved.
-#define ZS_P2P 0
+#define ZMQ_P2P 0
// Socket to distribute data. Recv fuction is not implemeted for this socket
// type. Messages are distributed in fanout fashion to all peers.
-#define ZS_PUB 1
+#define ZMQ_PUB 1
// Socket to subscribe to distributed data. Send function is not implemented
// for this socket type. However, subscribe function can be used to modify the
// message filter.
-#define ZS_SUB 2
+#define ZMQ_SUB 2
// Socket to send requests on and receive replies from. Requests are
// load-balanced among all the peers. This socket type doesn't allow for more
// recv's that there were send's.
-#define ZS_REQ 3
+#define ZMQ_REQ 3
// Socket to receive requests from and send replies to. This socket type allows
// only an alternated sequence of recv's and send's. Each send is routed to
// the peer that the previous recv delivered message from.
-#define ZS_REP 4
+#define ZMQ_REP 4
// Prototype for the message body deallocation functions.
// It is deliberately defined in the way to comply with standard C free.
-typedef void (zs_free_fn) (void *data);
+typedef void (zmq_free_fn) (void *data);
// A message. If 'shared' is true, message content pointed to by 'content'
// is shared, i.e. reference counting is used to manage its lifetime
// rather than straighforward malloc/free. struct zs_msg_content is
// not declared in the API.
-struct zs_msg
+struct zmq_msg
{
- struct zs_msg_content *content;
+ struct zmq_msg_content *content;
unsigned char shared;
uint16_t vsm_size;
- unsigned char vsm_data [ZS_MAX_VSM_SIZE];
+ unsigned char vsm_data [ZMQ_MAX_VSM_SIZE];
};
// TODO: Different options...
-struct zs_opts
+struct zmq_opts
{
uint64_t hwm;
uint64_t lwm;
@@ -107,41 +107,41 @@ struct zs_opts
};
// Initialise an empty message (zero bytes long).
-ZS_EXPORT int zs_msg_init (zs_msg *msg);
+ZMQ_EXPORT int zmq_msg_init (zmq_msg *msg);
// Initialise a message 'size' bytes long.
//
// Errors: ENOMEM - the size is too large to allocate.
-ZS_EXPORT int zs_msg_init_size (zs_msg *msg, size_t size);
+ZMQ_EXPORT int zmq_msg_init_size (zmq_msg *msg, size_t size);
// Initialise a message from an existing buffer. Message isn't copied,
// instead 0SOCKETS infrastructure take ownership of the buffer and call
// deallocation functio (ffn) once it's not needed anymore.
-ZS_EXPORT int zs_msg_init_data (zs_msg *msg, void *data, size_t size,
- zs_free_fn *ffn);
+ZMQ_EXPORT int zmq_msg_init_data (zmq_msg *msg, void *data, size_t size,
+ zmq_free_fn *ffn);
// Deallocate the message.
-ZS_EXPORT int zs_msg_close (zs_msg *msg);
+ZMQ_EXPORT int zmq_msg_close (zmq_msg *msg);
// Move the content of the message from 'src' to 'dest'. The content isn't
// copied, just moved. 'src' is an empty message after the call. Original
// content of 'dest' message is deallocated.
-ZS_EXPORT int zs_msg_move (zs_msg *dest, zs_msg *src);
+ZMQ_EXPORT int zmq_msg_move (zmq_msg *dest, zmq_msg *src);
// Copy the 'src' message to 'dest'. The content isn't copied, instead
// reference count is increased. Don't modify the message data after the
// call as they are shared between two messages. Original content of 'dest'
// message is deallocated.
-ZS_EXPORT int zs_msg_copy (zs_msg *dest, zs_msg *src);
+ZMQ_EXPORT int zmq_msg_copy (zmq_msg *dest, zmq_msg *src);
// Returns pointer to message data.
-ZS_EXPORT void *zs_msg_data (zs_msg *msg);
+ZMQ_EXPORT void *zmq_msg_data (zmq_msg *msg);
// Return size of message data (in bytes).
-ZS_EXPORT size_t zs_msg_size (zs_msg *msg);
+ZMQ_EXPORT size_t zmq_msg_size (zmq_msg *msg);
// Returns type of the message.
-ZS_EXPORT int zs_msg_type (zs_msg *msg);
+ZMQ_EXPORT int zmq_msg_type (zmq_msg *msg);
// Initialise 0SOCKETS context. 'app_threads' specifies maximal number
// of application threads that can have open sockets at the same time.
@@ -149,55 +149,56 @@ ZS_EXPORT int zs_msg_type (zs_msg *msg);
//
// Errors: EINVAL - one of the arguments is less than zero or there are no
// threads declared at all.
-ZS_EXPORT void *zs_init (int app_threads, int io_threads);
+ZMQ_EXPORT void *zmq_init (int app_threads, int io_threads);
// Deinitialise 0SOCKETS context including all the open sockets. Closing
-// sockets after zs_term has been called will result in undefined behaviour.
-ZS_EXPORT int zs_term (void *context);
+// sockets after zmq_term has been called will result in undefined behaviour.
+ZMQ_EXPORT int zmq_term (void *context);
// Open a socket.
//
// Errors: EINVAL - invalid socket type.
// EMFILE - the number of application threads entitled to hold open
// sockets at the same time was exceeded.
-ZS_EXPORT void *zs_socket (void *context, int type);
+ZMQ_EXPORT void *zmq_socket (void *context, int type);
// Close the socket.
-ZS_EXPORT int zs_close (void *s);
+ZMQ_EXPORT int zmq_close (void *s);
// Bind the socket to a particular address.
-ZS_EXPORT int zs_bind (void *s, const char *addr, zs_opts *opts);
+ZMQ_EXPORT int zmq_bind (void *s, const char *addr, zmq_opts *opts);
// Connect the socket to a particular address.
-ZS_EXPORT int zs_connect (void *s, const char *addr, zs_opts *opts);
+ZMQ_EXPORT int zmq_connect (void *s, const char *addr, zmq_opts *opts);
// Subscribe for the subset of messages identified by 'criteria' argument.
-ZS_EXPORT int zs_subscribe (void *s, const char *criteria);
+ZMQ_EXPORT int zmq_subscribe (void *s, const char *criteria);
// Send the message 'msg' to the socket 's'. 'flags' argument can be
// combination of following values:
// ZS_NOBLOCK - if message cannot be sent, return immediately.
// ZS_NOFLUSH - message won't be sent immediately. It'll be sent with either
// subsequent flushing send or explicit call to zs_flush function.
//
// Errors: EAGAIN - message cannot be sent at the moment (applies only to
// non-blocking send).
// ENOTSUP - function isn't supported by particular socket type.
-ZS_EXPORT int zs_send (void *s, zs_msg *msg, int flags);
+ZMQ_EXPORT int zmq_send (void *s, zmq_msg *msg, int flags);
-// Flush the messages that were send using ZS_NOFLUSH flag down the stream.
+// Flush the messages that were send using ZMQ_NOFLUSH flag down the stream.
//
// Errors: ENOTSUP - function isn't supported by particular socket type.
-ZS_EXPORT int zs_flush (void *s);
+ZMQ_EXPORT int zmq_flush (void *s);
// Send a message from the socket 's'. 'flags' argument can be combination
// of following values:
// ZS_NOBLOCK - if message cannot be received, return immediately.
//
// Errors: EAGAIN - message cannot be received at the moment (applies only to
// non-blocking receive).
// ENOTSUP - function isn't supported by particular socket type.
-ZS_EXPORT int zs_recv (void *s, zs_msg *msg, int flags);
+ZMQ_EXPORT int zmq_recv (void *s, zmq_msg *msg, int flags);
#ifdef __cplusplus
}
@@ -27,75 +27,75 @@ extern "C" {
// The operation should be performed in non-blocking mode. I.e. if it cannot
// be processed immediately, error should be returned with errno set to EAGAIN.
-#define ZS_NOBLOCK 1
+#define ZMQ_NOBLOCK 1
-// zs_send should not flush the message downstream immediately. Instead, it
-// should batch ZS_NOFLUSH messages and send them downstream only when zs_flush
+// zmq_send should not flush the message downstream immediately. Instead, it
+// should batch ZMQ_NOFLUSH messages and send them downstream only if zmq_flush
// is invoked. This is an optimisation for cases where several messages are
// sent in a single business transaction. However, the effect is measurable
@@ -27,75 +27,75 @@ extern "C" {
// only in extremely high-perf scenarios (million messages a second or so).
// If that's not your case, use standard flushing send instead. See exchange
-// example for illustration of ZS_NOFLUSH functionality.
-#define ZS_NOFLUSH 2
+// example for illustration of ZMQ_NOFLUSH functionality.
+#define ZMQ_NOFLUSH 2
// Socket to communicate with a single peer. Allows for a singe connect or a
// single accept. There's no message routing or message filtering involved.
@@ -27,75 +27,75 @@ extern "C" {
// A message. If 'shared' is true, message content pointed to by 'content'
// is shared, i.e. reference counting is used to manage its lifetime
-// rather than straighforward malloc/free. struct zs_msg_content is
+// rather than straighforward malloc/free. struct zmq_msg_content is
// not declared in the API.
@@ -149,55 +149,56 @@ ZS_EXPORT int zs_msg_type (zs_msg *msg);
// Send the message 'msg' to the socket 's'. 'flags' argument can be
// combination of following values:
-// ZS_NOBLOCK - if message cannot be sent, return immediately.
-// ZS_NOFLUSH - message won't be sent immediately. It'll be sent with either
-// subsequent flushing send or explicit call to zs_flush function.
+// ZMQ_NOBLOCK - if message cannot be sent, return immediately.
+// ZMQ_NOFLUSH - message won't be sent immediately. It'll be sent with either
+// subsequent flushing send or explicit call to zmq_flush
+// function.
//
// Errors: EAGAIN - message cannot be sent at the moment (applies only to
@@ -149,55 +149,56 @@ ZS_EXPORT int zs_msg_type (zs_msg *msg);
// Send a message from the socket 's'. 'flags' argument can be combination
// of following values:
-// ZS_NOBLOCK - if message cannot be received, return immediately.
+// ZMQ_NOBLOCK - if message cannot be received, return immediately.
//
// Errors: EAGAIN - message cannot be received at the moment (applies only to